ChatHistoryOptions class
Constructors
- ChatHistoryOptions({NamePosition namePosition = NamePosition.top, double? fontSize, Color? fontColor, int? maxLines, Color? backgroundColor, Color? borderColor, double? borderWidth, double? borderRadius, EdgeInsetsGeometry? borderPadding})
-
const
Properties
- backgroundColor → Color?
-
final
- borderColor → Color?
-
final
- borderPadding → EdgeInsetsGeometry?
-
final
- borderRadius → double?
-
final
- borderWidth → double?
-
final
- fontColor → Color?
-
final
- fontSize → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLines → int?
-
final
- namePosition → NamePosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited